(create-mstp-network {:keys [local-network-number mstp-config]
:as device-config})Return an MstpNetwork object, configured with either a slave or a master node for the local-device. This class does not have a dedicated 'builder' like the IP network does, so we'll call its constructor directly.
Return an MstpNetwork object, configured with either a slave or a master node for the local-device. This class does not have a dedicated 'builder' like the IP network does, so we'll call its constructor directly.
(get-any-ip)Return the first IPv4 found.
Return the first IPv4 found.
(get-broadcast-address local-ip)Given a local-ip, return the broadcast address
Given a local-ip, return the broadcast address
(get-interface-from-ip ip)Given an IP address, return the interface.
Given an IP address, return the interface.
(get-interfaces)Return the list of interfaces on this machine.
Return the list of interfaces on this machine.
(interfaces-and-ips)Return a list of interfaces and their IPs. ({:interface "wlan0", :ips ("192.168.0.2")})
Return a list of interfaces and their IPs.
({:interface "wlan0", :ips ("192.168.0.2")})(ip-network-builder {:keys [broadcast-address local-address local-network-number
port reuse-address]})Return an IP network object.
Return an IP network object.
(ipv4-from-interface interface)Return a list of available IPs from the interface. Remove any loopback address.
As BACnet doesn't support IPv6 yet, just keep IPv4.
Return a list of available IPs from the interface. Remove any loopback address. As BACnet doesn't support IPv6 yet, just keep IPv4.
(resolve-dns IP-or-url)Return the IP of a given url, or simply return the IP unchanged
Return the IP of a given url, or simply return the IP unchanged
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |